Faster Zswap With Patches To Batch The Writeback I/O
- Reference: 0001662709
- News link: https://www.phoronix.com/news/Faster-Zswap-Batch-Writeback-IO
- Source link:
Separate from the Zswap patches posted earlier this week providing [1]rather significant performance improvements , a separate patch series for Zswap posted to the Linux kernel mailing list are providing more incremental gains. In the presence of Zswap, the patches provided 3~4% time-savings when compiling the Linux kernel as a sample workload.
[2]
Alexandre Ghiti posted the patches to batch the writeback I/O for Zswap, explaining:
"Since commit 8f29aa226f82 ("mm/swap: introduce struct swap_io_ctx"), reclaim merges the swap writes of folios with consecutive slots into a single bio, but zswap writeback still issues one IO per entry. Patch 1 makes each zswap LRU walk batch its writeback IO. Patch 2 plugs the walk, so that the block layer can merge what the batch cannot."
[3]The patches are under review and so far the review comments have been favorable. With 3~4% build time savings for the Linux kernel in testing. every bit of improvement helps amid the increased interest around ZRAM and Zswap in today's environment.
[1] https://www.phoronix.com/news/Linux-Better-Zswap-Performance
[2] https://www.phoronix.com/image-viewer.php?id=2026&image=more_zswwap_lrg
[3] https://lore.kernel.org/all/20261007153507.50715-1-alex@ghiti.fr/